locate — EQcorrscan 0.1.0 documentation

# locate

Functions to locate earthquakes detected by EQcorrscan - designed first tolocate stacks of detections to give family locations. Extensions may later bewritten.

Copyright 2015 Calum Chamberlain

This file is part of EQcorrscan.

> EQcorrscan is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

> EQcorrscan is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

> You should have received a copy of the GNU General Public License along with EQcorrscan. If not, see <http://www.gnu.org/licenses/>.

`locate.` `cross_net`(stream, env=False, debug=0, master=False)

  Function to generate picks for each channel based on optimal moveout defined by maximum cross-correaltion with master trace. Master trace will be the first trace in the stream.

  Parameters: | stream – Stream to pick envelope (bool) – To compute cross-correlations on the envelope or not. debug (int) – Debug level from 0-5 master (obspy.Trace) – Trace to use as master, if False, will use the first tracein stream.
  Returns: | list of pick class

`locate.` `stalta_pick`(stream, stalen, ltalen, trig_on, trig_off, freqmin=False, freqmax=False, debug=0, show=False)

  Simple sta-lta (short-term average/long-term average) picker, using obspy’s stalta routine to generate the characteristic function.

  Currently very basic quick wrapper, there are many other (better) options in obspy, found (here)[http://docs.obspy.org/packages/autogen/obspy.signal.trigger.html].

  Parameters: | stream (obspy.Stream) – The stream to pick on, can be any number of channels. stalen (float) – Length of the short-term average window in seconds. ltalen (float) – Length of the long-term average window in seconds. trig_on (float) – sta/lta ratio to trigger a detection/pick trig_off (float) – sta/lta ratio to turn the trigger off - no further pickswill be made between exceeding trig_on until trig_off is reached. freqmin (float) – Low-cut frequency in Hz for bandpass filter freqmax (float) – High-cut frequency in Hz for bandpass filter debug (int) – Debug output level from 0-5. show (bool) – Show picks on waveform.
  Returns: | list of pick class.

`locate.` `synth_compare`(stream, stream_list, cores=4, debug=0)

  Compare a specific stream to a list of synthetic templates, or earthquakes of known source and find the best matching event.

  Parameters: | stream (:class:obspy.Stream) – Stream to be compared to streams with known locations. stream_list (list) – List of streams with known locations cores (int) – Number of cores to parallel over debug (int) – Debug level, high is more debug
  Returns: | int, float: index of best match and cross-correlation sum